@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.113_02';
+our $VERSION = '0.114_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Dec 27 14:47:44 2018 GMT
+# on Thu Jan 24 17:48:57 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1775,7 +1775,7 @@ __PACKAGE__->status( add => 25578, iridium => 'D', 'Iridium 11', 'Decayed 2018-1
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
 __PACKAGE__->status( add => 27372, iridium => '+', 'Iridium 91', '' );
-__PACKAGE__->status( add => 27373, iridium => '-', 'Iridium 90', 'Tumbling' );
+__PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 8
 #       Spare [S]: 5
-#    Tumbling [-]: 33
-#     Decayed [D]: 51
+#    Tumbling [-]: 32
+#     Decayed [D]: 52
 
 1;
 
@@ -1945,7 +1945,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2018 by Thomas R. Wyant, III
+Copyright (C) 2005-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
